@@ -38,10 +38,10 @@
 #include "windows.h"
 #endif
 
-#include "display.h"
-#include "logger.h"
+#include "gl.h"
 
-#include <stdexcept>
+#include <string>
+#include <exception>
 #include <vector>
 
 extern std::string gSDLAppConfDir;
@@ -97,8 +97,10 @@ class SDLApp {
 protected:
     int  min_delta_msec;
     bool appFinished;
+
     void stop(int return_code);
 
+    virtual bool handleEvent(SDL_Event& event);
 public:
     float fps;
 
@@ -138,7 +140,10 @@ public:
     virtual void mouseClick(SDL_MouseButtonEvent *e) {};
     virtual void keyPress(SDL_KeyboardEvent *e) {};
 
-#if SDL_VERSION_ATLEAST(1,3,0)
+#if SDL_VERSION_ATLEAST(2,0,0)
+    virtual void textInput(SDL_TextInputEvent* e)  {};
+    virtual void textEdit(SDL_TextEditingEvent* e) {};
+
     virtual void mouseWheel(SDL_MouseWheelEvent *e) {};
 #endif
 
