@@ -18,19 +18,16 @@
 #ifndef GITLOG_H
 #define GITLOG_H
 
-#include "../gource_settings.h"
 #include "commitlog.h"
 
-#include <unistd.h>
-
-extern std::string gGourceGitLogCommand;
-
 class GitCommitLog : public RCommitLog {
 protected:
     bool parseCommit(RCommit& commit);
     BaseLog* generateLog(const std::string& dir);
 public:
     GitCommitLog(const std::string& logfile);
+    
+    static std::string logCommand();
 };
 
 #endif
