@@ -45,7 +45,7 @@ void GourceSettings::help(bool extended_help) {
 
     printf("Gource v%s\n", GOURCE_VERSION);
 
-    printf("Usage: gource [OPTIONS] [PATH]\n");
+    printf("Usage: gource [options] [path]\n");
     printf("\nOptions:\n");
     printf("  -h, --help                       Help\n\n");
     printf("  -WIDTHxHEIGHT, --viewport        Set viewport size\n");
@@ -130,8 +130,8 @@ if(extended_help) {
     printf("  --transparent            Make the background transparent\n\n");
 
     printf("  --user-filter REGEX      Ignore usernames matching this regex\n");
-    printf("  --file-filter REGEX      Ignore files matching this regex\n");
-    printf("  --file-show-filter REGEX Show only files matching this regex\n\n");
+    printf("  --file-filter REGEX      Ignore file paths matching this regex\n");
+    printf("  --file-show-filter REGEX Show only file paths matching this regex\n\n");
 
     printf("  --user-friction SECONDS  Change the rate users slow down (default: 0.67)\n");
     printf("  --user-scale SCALE       Change scale of users (default: 1.0)\n");
@@ -780,6 +780,10 @@ void GourceSettings::importGourceSettings(ConfFile& conffile, ConfSection* gourc
         if(!entry->hasValue()) conffile.entryException(entry, "specify caption file (filename)");
 
         caption_file = entry->getString();
+
+        if(!boost::filesystem::exists(caption_file)) {
+            conffile.entryException(entry, "caption file not found");
+        }
     }
 
     if((entry = gource_settings->getEntry("caption-duration")) != 0) {
